---
id: 20211123212328
title: Render markdown document as a card
tags: [template, zettel, markdown]
---

# Render markdown document as a card

Markdown documents fulfilling the [requirements](20211122195910) will be rendered as cards. The card has three sections:

1. Header with [metadata](20211123213357)
2. Body with content
3. Footer with [references](20211123213414)

Code blocks will get syntax highlighted using [Pygments](https://pypi.org/project/Pygments/). Please consider installing [PyMdown Extensions](https://facelessuser.github.io/pymdown-extensions/installation/) and enable `pymdownx.superfences` markdown_extension in `mkdocs.yml` to get syntax highlighting in code blocks nested in lists.
